aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java')
-rw-r--r--moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java62
1 files changed, 31 insertions, 31 deletions
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java
index e6fee6f..3f6af21 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/KeyValueType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,34 +10,34 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlElementRef;
-import javax.xml.bind.annotation.XmlElementRefs;
-import javax.xml.bind.annotation.XmlMixed;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.JAXBElement;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlElementRef;
+import jakarta.xml.bind.annotation.XmlElementRefs;
+import jakarta.xml.bind.annotation.XmlMixed;
+import jakarta.xml.bind.annotation.XmlType;
import org.w3c.dom.Element;
/**
- * <p>Java class for KeyValueType complex type.
+ * <p>Java-Klasse für KeyValueType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="KeyValueType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;choice>
- * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}DSAKeyValue"/>
- * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}RSAKeyValue"/>
- * &lt;any processContents='lax' namespace='##other'/>
- * &lt;/choice>
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="KeyValueType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;choice&gt;
+ * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}DSAKeyValue"/&gt;
+ * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}RSAKeyValue"/&gt;
+ * &lt;any processContents='lax' namespace='##other'/&gt;
+ * &lt;/choice&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -49,8 +49,8 @@ import org.w3c.dom.Element;
public class KeyValueType {
@XmlElementRefs({
- @XmlElementRef(name = "RSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false),
- @XmlElementRef(name = "DSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false)
+ @XmlElementRef(name = "DSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false),
+ @XmlElementRef(name = "RSAKeyValue", namespace = "http://www.w3.org/2000/09/xmldsig#", type = JAXBElement.class, required = false)
})
@XmlMixed
@XmlAnyElement(lax = true)
@@ -62,7 +62,7 @@ public class KeyValueType {
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the content property.
*
* <p>
@@ -74,11 +74,11 @@ public class KeyValueType {
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link String }
- * {@link JAXBElement }{@code <}{@link RSAKeyValueType }{@code >}
* {@link JAXBElement }{@code <}{@link DSAKeyValueType }{@code >}
- * {@link Element }
+ * {@link JAXBElement }{@code <}{@link RSAKeyValueType }{@code >}
* {@link Object }
+ * {@link String }
+ * {@link Element }
*
*
*/
@@ -62,7 +62,7 @@ public class KeyValueType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the content property.
*